@@ -1,10 +1,10 @@
 '''
 Author: BDFD
 Date: 2022-02-24 15:23:11
-LastEditTime: 2022-04-27 23:52:07
+LastEditTime: 2022-06-14 11:55:20
 LastEditors: BDFD
 Description: 
-FilePath: \5.2-PyPi-WES_Calculation\WES_Calculation\gumbel.py
+FilePath: \Section5.2-PyPi-WES_Calculation\WES_Calculation\gumbel.py
 '''
 import matplotlib.pyplot as plt
 from matplotlib.ticker import FixedLocator, FixedFormatter
@@ -265,6 +265,7 @@ def gumbel(pq, unitt, unitx, i1, i2, i3, meanx, sdx, n, dataolist):
     data3 = ()
     data4 = ()
     data5 = ()
+    data6 = ()
     heading1 = ''
     heading2 = ''
     ending = ''
@@ -339,9 +340,9 @@ def gumbel(pq, unitt, unitx, i1, i2, i3, meanx, sdx, n, dataolist):
             note5.append(note_5_1)
             data5 += (('Kolmogorov-Smirnov 检验值',str(round(KS1,3)),str(round(KS2,3))),)
             if n>=nlC2:
-                data5 += (('Chi-Squared 检验值',str(round(C21,3)),str(round(C22,3))),)
+                data6 += (('Chi-Squared 检验值',str(round(C21,3)),str(round(C22,3))),)
             else:
-                data5 += (('Chi-Squared 检验值','无 (因为样本容量小于'+str(nlC2)+')','无'),)
+                data6 += (('Chi-Squared 检验值','无 (因为样本容量小于'+str(nlC2)+')'),)
             # print('')#20220310
         ending ='---结果展示结束---'#20220310
             # data=()
@@ -397,4 +398,4 @@ def gumbel(pq, unitt, unitx, i1, i2, i3, meanx, sdx, n, dataolist):
         plot_url = base64.b64encode(img.getvalue()).decode()
         plt.close("all")
         # return plot_url
-    return plot_url, note1, note2, note3, data3, note4, data4, note5, data5, heading1, heading2, ending
\ No newline at end of file
+    return plot_url, n, note1, note2, note3, data3, note4, data4, note5, data5, data6, heading1, heading2, ending
\ No newline at end of file
